@@ -1403,6 +1403,8 @@ ags_live_dssi_bridge_load(AgsLiveDssiBridge *live_dssi_bridge)
   GList *start_list, *list;
   GList *start_plugin_port, *plugin_port;
   
+  gchar *port_name;
+
   unsigned long samplerate;
   unsigned long effect_index;
   gdouble step;
@@ -1539,10 +1541,16 @@ ags_live_dssi_bridge_load(AgsLiveDssiBridge *live_dssi_bridge)
       gchar *plugin_name;
       gchar *control_port;
       
-      guint step_count;
+      guint port_index;
+      guint scale_precision;
+      gdouble step_count;
       gboolean disable_seemless;
+      gboolean do_step_conversion;
+
+      pthread_mutex_t *plugin_port_mutex;
 
       disable_seemless = FALSE;
+      do_step_conversion = FALSE;
       
       if(x == AGS_EFFECT_BULK_COLUMNS_COUNT){
 	x = 0;
@@ -1565,20 +1573,45 @@ ags_live_dssi_bridge_load(AgsLiveDssiBridge *live_dssi_bridge)
 	}
       }
 
-      step_count = AGS_DIAL_DEFAULT_PRECISION;
+      scale_precision = AGS_DIAL_DEFAULT_PRECISION;
+      step_count = AGS_LADSPA_CONVERSION_DEFAULT_STEP_COUNT;
 
       if(ags_plugin_port_test_flags(plugin_port->data, AGS_PLUGIN_PORT_INTEGER)){
-	step_count = AGS_PLUGIN_PORT(plugin_port->data)->scale_steps;
+	guint scale_steps;
+	
+	g_object_get(plugin_port->data,
+		     "scale-steps", &scale_steps,
+		     NULL);
+
+	step_count =
+	  scale_precision = (gdouble) scale_steps;
 
 	disable_seemless = TRUE;	
       }
 
+      /* get plugin port mutex */
+      pthread_mutex_lock(ags_plugin_port_get_class_mutex());
+
+      plugin_port_mutex = AGS_PLUGIN_PORT(plugin_port->data)->obj_mutex;
+      
+      pthread_mutex_unlock(ags_plugin_port_get_class_mutex());
+
+      /* get port name */
+      pthread_mutex_lock(plugin_port_mutex);
+
+      port_name = g_strdup(AGS_PLUGIN_PORT(plugin_port->data)->port_name);
+      port_index = AGS_PLUGIN_PORT(plugin_port->data)->port_index;
+      
+      pthread_mutex_unlock(plugin_port_mutex);
+
       /* add bulk member */
       plugin_name = g_strdup_printf("dssi-%u",
 				    dssi_plugin->unique_id);
-      control_port = g_strdup_printf("%u/%lu",
-				     k,
+
+      control_port = g_strdup_printf("%u/%u",
+				     k + 1,
 				     port_count);
+
       bulk_member = (AgsBulkMember *) g_object_new(AGS_TYPE_BULK_MEMBER,
 						   "widget-type", widget_type,
 						   "widget-label", AGS_PLUGIN_PORT(plugin_port->data)->port_name,
@@ -1587,7 +1620,10 @@ ags_live_dssi_bridge_load(AgsLiveDssiBridge *live_dssi_bridge)
 						   "effect", live_dssi_bridge->effect,
 						   "specifier", AGS_PLUGIN_PORT(plugin_port->data)->port_name,
 						   "control-port", control_port,
-						   "steps", step_count,
+						   "port-index", port_index,
+						   "control-port", control_port,
+						   "scale-precision", scale_precision,
+						   "step-count", step_count,
 						   NULL);
       child_widget = ags_bulk_member_get_widget(bulk_member);
 
@@ -1631,6 +1667,8 @@ ags_live_dssi_bridge_load(AgsLiveDssiBridge *live_dssi_bridge)
 	}
     
 	ladspa_conversion->flags |= AGS_LADSPA_CONVERSION_LOGARITHMIC;
+
+	do_step_conversion = TRUE;
       }
 
       bulk_member->conversion = (AgsConversion *) ladspa_conversion;
@@ -1649,7 +1687,9 @@ ags_live_dssi_bridge_load(AgsLiveDssiBridge *live_dssi_bridge)
 	GtkAdjustment *adjustment;
 
 	LADSPA_Data lower_bound, upper_bound;
+	gdouble lower, upper;
 	LADSPA_Data default_value;
+	gdouble control_value;
 	
 	dial = (AgsDial *) child_widget;
 
@@ -1658,43 +1698,71 @@ ags_live_dssi_bridge_load(AgsLiveDssiBridge *live_dssi_bridge)
 	}
 
 	/* add controls of ports and apply range  */
+	pthread_mutex_lock(plugin_port_mutex);
+	
 	lower_bound = g_value_get_float(AGS_PLUGIN_PORT(plugin_port->data)->lower_value);
 	upper_bound = g_value_get_float(AGS_PLUGIN_PORT(plugin_port->data)->upper_value);
 
+	pthread_mutex_unlock(plugin_port_mutex);
+
+	if(do_step_conversion){
+	  g_object_set(ladspa_conversion,
+		       "lower", lower_bound,
+		       "upper", upper_bound,
+		       NULL);
+
+	  lower = 0.0;
+	  upper = AGS_LADSPA_CONVERSION_DEFAULT_STEP_COUNT - 1.0;
+	  
+#if 0
+	  if(!disable_seemless){
+	    g_object_get(ladspa_conversion,
+			 "step-count", &step_count,
+			 NULL);
+	  }
+#endif
+	}else{
+	  lower = lower_bound;
+	  upper = upper_bound;
+	}
+	
 	adjustment = (GtkAdjustment *) gtk_adjustment_new(0.0, 0.0, 1.0, 0.1, 0.1, 0.0);
 	g_object_set(dial,
 		     "adjustment", adjustment,
 		     NULL);
 
-	if(upper_bound >= 0.0 && lower_bound >= 0.0){
-	  step = (upper_bound - lower_bound) / step_count;
-	}else if(upper_bound < 0.0 && lower_bound < 0.0){
-	  step = -1.0 * (lower_bound - upper_bound) / step_count;
+	if(upper >= 0.0 && lower >= 0.0){
+	  step = (upper - lower) / step_count;
+	}else if(upper < 0.0 && lower < 0.0){
+	  step = -1.0 * (lower - upper) / step_count;
 	}else{
-	  step = (upper_bound - lower_bound) / step_count;
+	  step = (upper - lower) / step_count;
 	}
-
+	
 	gtk_adjustment_set_step_increment(adjustment,
 					  step);
 	gtk_adjustment_set_lower(adjustment,
-				 lower_bound);
+				 lower);
 	gtk_adjustment_set_upper(adjustment,
-				 upper_bound);
+				 upper);
 
-	default_value = (LADSPA_Data) g_value_get_float(AGS_PLUGIN_PORT(plugin_port->data)->default_value);
-
-	if(ladspa_conversion != NULL){
-	  //	  default_value = ags_ladspa_conversion_convert(ladspa_conversion,
-	  //						default_value,
-	  //						TRUE);
-	}
+	/* get/set default value */
+	pthread_mutex_lock(plugin_port_mutex);
 	
-	gtk_adjustment_set_value(adjustment,
-				 default_value);
+	default_value = (float) g_value_get_float(AGS_PLUGIN_PORT(plugin_port->data)->default_value);
 
-#ifdef AGS_DEBUG
-	g_message("dssi bounds: %f %f", lower_bound, upper_bound);
-#endif
+	pthread_mutex_unlock(plugin_port_mutex);
+
+	control_value = default_value;
+	
+	if(ladspa_conversion != NULL){
+	  control_value = ags_conversion_convert(ladspa_conversion,
+						 default_value,
+						 TRUE);
+	}
+
+	gtk_adjustment_set_value(adjustment,
+				 control_value);
       }else if(AGS_IS_INDICATOR(child_widget) ||
 	       AGS_IS_LED(child_widget)){
 	g_hash_table_insert(ags_effect_bulk_indicator_queue_draw,
