@@ -129,6 +129,10 @@ struct _AgsCoreAudioDevout
   guint samplerate;
 
   pthread_mutex_t **buffer_mutex;
+
+  guint sub_block_count;
+  pthread_mutex_t **sub_block_mutex;
+
   void** buffer;
 
   double bpm; // beats per minute
